searchNodes=[{"doc":"Orchestrator of a back-pressured backfill strategy for Ecto repos. Starts a producer process and dynamically start consumers, the amount of consumers is determined by the availability of resources on your infrastructure, such as available database connections or I/O usage. Define a module to execute the backfill, which must use EctoBackfiller and implement its callbacks. Lets imagine a silly example to illustrate the use of the library. Suppose you have a User schema described as: defmodule MyApp.Users.User do use Ecto.Schema schema do field :email_verified_at , :naive_datetime end end And later on, your business requirements takes you to add email_verified field as a boolean on the schema representing if the user has verified the email. Then you write up the migration and have to update the new column all existing users before execution of the migration. To do so, you can write a module using EctoBackfiller as: defmodule MyApp.Backfills.UserEmailVerifiedBackfill do use EctoBackfiller , repo : MyApp.Repo alias MyApp.Users alias MyApp.Users.User @impl true def query , do : Ecto.Queryable . to_query ( User ) @impl true def step , do : 5 @impl true def handle_batch ( users ) do Enum . each ( users , fn user -&gt; if is_nil ( user . email_verified_at ) do { :ok , user } = Users . update ( user , %{ email_verified : false } ) else { :ok , user } = Users . update ( user , %{ email_verified : true } ) end end ) end end Now you are ready to start executing it and to do so you must start the Supervisor, which will be named as the backfill module's name, or in other words, it is a unique proccess per backfill module. Inside the application IEx session: alias MyApp.Backfills.UserEmailVerifiedBackfill UserEmailVerifiedBackfill . start_link ( ) :ok UserEmailVerifiedBackfill . add_consumer ( ) :ok UserEmailVerifiedBackfill . start ( ) :ok You may add or more consumers on the fly, based on how the application performs based on the step used and the number of consumers subscribed.","ref":"EctoBackfiller.html","title":"EctoBackfiller","type":"behaviour"},{"doc":"Handles the backfill logic given a list of data","ref":"EctoBackfiller.html#c:handle_batch/1","title":"EctoBackfiller.handle_batch/1","type":"callback"},{"doc":"Queryable used on Repo.all/2 to fetch chunks of data","ref":"EctoBackfiller.html#c:query/0","title":"EctoBackfiller.query/0","type":"callback"},{"doc":"Amount of data fetched per step","ref":"EctoBackfiller.html#c:step/0","title":"EctoBackfiller.step/0","type":"callback"},{"doc":"","ref":"EctoBackfiller.Consumer.html","title":"EctoBackfiller.Consumer","type":"module"},{"doc":"","ref":"EctoBackfiller.Consumer.html#start_link/1","title":"EctoBackfiller.Consumer.start_link/1","type":"function"},{"doc":"","ref":"EctoBackfiller.DynamicSupervisor.html","title":"EctoBackfiller.DynamicSupervisor","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"EctoBackfiller.DynamicSupervisor.html#child_spec/1","title":"EctoBackfiller.DynamicSupervisor.child_spec/1","type":"function"},{"doc":"","ref":"EctoBackfiller.DynamicSupervisor.html#start_consumer/2","title":"EctoBackfiller.DynamicSupervisor.start_consumer/2","type":"function"},{"doc":"","ref":"EctoBackfiller.DynamicSupervisor.html#start_link/1","title":"EctoBackfiller.DynamicSupervisor.start_link/1","type":"function"},{"doc":"","ref":"EctoBackfiller.DynamicSupervisor.html#start_producer/2","title":"EctoBackfiller.DynamicSupervisor.start_producer/2","type":"function"},{"doc":"","ref":"EctoBackfiller.Producer.html","title":"EctoBackfiller.Producer","type":"module"},{"doc":"","ref":"EctoBackfiller.Producer.html#add_consumer/3","title":"EctoBackfiller.Producer.add_consumer/3","type":"function"},{"doc":"","ref":"EctoBackfiller.Producer.html#get_consumers/1","title":"EctoBackfiller.Producer.get_consumers/1","type":"function"},{"doc":"","ref":"EctoBackfiller.Producer.html#put_subscription/3","title":"EctoBackfiller.Producer.put_subscription/3","type":"function"},{"doc":"","ref":"EctoBackfiller.Producer.html#running?/1","title":"EctoBackfiller.Producer.running?/1","type":"function"},{"doc":"","ref":"EctoBackfiller.Producer.html#start_link/1","title":"EctoBackfiller.Producer.start_link/1","type":"function"},{"doc":"","ref":"ExampleApplication.Backfills.UserEmailVerifiedBackfill.html","title":"ExampleApplication.Backfills.UserEmailVerifiedBackfill","type":"module"},{"doc":"Adds an inactive consumer to supervision tree.","ref":"ExampleApplication.Backfills.UserEmailVerifiedBackfill.html#add_consumer/0","title":"ExampleApplication.Backfills.UserEmailVerifiedBackfill.add_consumer/0","type":"function"},{"doc":"Subscribes all consumers that aren't already subscribed to producer.","ref":"ExampleApplication.Backfills.UserEmailVerifiedBackfill.html#start/0","title":"ExampleApplication.Backfills.UserEmailVerifiedBackfill.start/0","type":"function"},{"doc":"Starts supervisor and producer processes.","ref":"ExampleApplication.Backfills.UserEmailVerifiedBackfill.html#start_link/1","title":"ExampleApplication.Backfills.UserEmailVerifiedBackfill.start_link/1","type":"function"},{"doc":"Cancels all consumer subscriptions.","ref":"ExampleApplication.Backfills.UserEmailVerifiedBackfill.html#stop/0","title":"ExampleApplication.Backfills.UserEmailVerifiedBackfill.stop/0","type":"function"},{"doc":"","ref":"ExampleApplication.Repo.html","title":"ExampleApplication.Repo","type":"module"},{"doc":"Callback implementation for Ecto.Repo.aggregate/3 .","ref":"ExampleApplication.Repo.html#aggregate/3","title":"ExampleApplication.Repo.aggregate/3","type":"function"},{"doc":"Callback implementation for Ecto.Repo.aggregate/4 .","ref":"ExampleApplication.Repo.html#aggregate/4","title":"ExampleApplication.Repo.aggregate/4","type":"function"},{"doc":"Callback implementation for Ecto.Repo.all/2 .","ref":"ExampleApplication.Repo.html#all/2","title":"ExampleApplication.Repo.all/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.checked_out?/0 .","ref":"ExampleApplication.Repo.html#checked_out?/0","title":"ExampleApplication.Repo.checked_out?/0","type":"function"},{"doc":"Callback implementation for Ecto.Repo.checkout/2 .","ref":"ExampleApplication.Repo.html#checkout/2","title":"ExampleApplication.Repo.checkout/2","type":"function"},{"doc":"","ref":"ExampleApplication.Repo.html#child_spec/1","title":"ExampleApplication.Repo.child_spec/1","type":"function"},{"doc":"Callback implementation for Ecto.Repo.config/0 .","ref":"ExampleApplication.Repo.html#config/0","title":"ExampleApplication.Repo.config/0","type":"function"},{"doc":"Callback implementation for Ecto.Repo.default_options/1 .","ref":"ExampleApplication.Repo.html#default_options/1","title":"ExampleApplication.Repo.default_options/1","type":"function"},{"doc":"Callback implementation for Ecto.Repo.delete!/2 .","ref":"ExampleApplication.Repo.html#delete!/2","title":"ExampleApplication.Repo.delete!/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.delete/2 .","ref":"ExampleApplication.Repo.html#delete/2","title":"ExampleApplication.Repo.delete/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.delete_all/2 .","ref":"ExampleApplication.Repo.html#delete_all/2","title":"ExampleApplication.Repo.delete_all/2","type":"function"},{"doc":"A convenience function for SQL-based repositories that forces all connections in the pool to disconnect within the given interval. See Ecto.Adapters.SQL.disconnect_all/3 for more information.","ref":"ExampleApplication.Repo.html#disconnect_all/2","title":"ExampleApplication.Repo.disconnect_all/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.exists?/2 .","ref":"ExampleApplication.Repo.html#exists?/2","title":"ExampleApplication.Repo.exists?/2","type":"function"},{"doc":"A convenience function for SQL-based repositories that executes an EXPLAIN statement or similar depending on the adapter to obtain statistics for the given query. See Ecto.Adapters.SQL.explain/4 for more information.","ref":"ExampleApplication.Repo.html#explain/3","title":"ExampleApplication.Repo.explain/3","type":"function"},{"doc":"Callback implementation for Ecto.Repo.get!/3 .","ref":"ExampleApplication.Repo.html#get!/3","title":"ExampleApplication.Repo.get!/3","type":"function"},{"doc":"Callback implementation for Ecto.Repo.get/3 .","ref":"ExampleApplication.Repo.html#get/3","title":"ExampleApplication.Repo.get/3","type":"function"},{"doc":"Callback implementation for Ecto.Repo.get_by!/3 .","ref":"ExampleApplication.Repo.html#get_by!/3","title":"ExampleApplication.Repo.get_by!/3","type":"function"},{"doc":"Callback implementation for Ecto.Repo.get_by/3 .","ref":"ExampleApplication.Repo.html#get_by/3","title":"ExampleApplication.Repo.get_by/3","type":"function"},{"doc":"Callback implementation for Ecto.Repo.get_dynamic_repo/0 .","ref":"ExampleApplication.Repo.html#get_dynamic_repo/0","title":"ExampleApplication.Repo.get_dynamic_repo/0","type":"function"},{"doc":"Callback implementation for Ecto.Repo.in_transaction?/0 .","ref":"ExampleApplication.Repo.html#in_transaction?/0","title":"ExampleApplication.Repo.in_transaction?/0","type":"function"},{"doc":"Callback implementation for Ecto.Repo.insert!/2 .","ref":"ExampleApplication.Repo.html#insert!/2","title":"ExampleApplication.Repo.insert!/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.insert/2 .","ref":"ExampleApplication.Repo.html#insert/2","title":"ExampleApplication.Repo.insert/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.insert_all/3 .","ref":"ExampleApplication.Repo.html#insert_all/3","title":"ExampleApplication.Repo.insert_all/3","type":"function"},{"doc":"Callback implementation for Ecto.Repo.insert_or_update!/2 .","ref":"ExampleApplication.Repo.html#insert_or_update!/2","title":"ExampleApplication.Repo.insert_or_update!/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.insert_or_update/2 .","ref":"ExampleApplication.Repo.html#insert_or_update/2","title":"ExampleApplication.Repo.insert_or_update/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.load/2 .","ref":"ExampleApplication.Repo.html#load/2","title":"ExampleApplication.Repo.load/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.one!/2 .","ref":"ExampleApplication.Repo.html#one!/2","title":"ExampleApplication.Repo.one!/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.one/2 .","ref":"ExampleApplication.Repo.html#one/2","title":"ExampleApplication.Repo.one/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.preload/3 .","ref":"ExampleApplication.Repo.html#preload/3","title":"ExampleApplication.Repo.preload/3","type":"function"},{"doc":"Callback implementation for Ecto.Repo.prepare_query/3 .","ref":"ExampleApplication.Repo.html#prepare_query/3","title":"ExampleApplication.Repo.prepare_query/3","type":"function"},{"doc":"Callback implementation for Ecto.Repo.put_dynamic_repo/1 .","ref":"ExampleApplication.Repo.html#put_dynamic_repo/1","title":"ExampleApplication.Repo.put_dynamic_repo/1","type":"function"},{"doc":"A convenience function for SQL-based repositories that executes the given query. See Ecto.Adapters.SQL.query!/4 for more information.","ref":"ExampleApplication.Repo.html#query!/3","title":"ExampleApplication.Repo.query!/3","type":"function"},{"doc":"A convenience function for SQL-based repositories that executes the given query. See Ecto.Adapters.SQL.query/4 for more information.","ref":"ExampleApplication.Repo.html#query/3","title":"ExampleApplication.Repo.query/3","type":"function"},{"doc":"A convenience function for SQL-based repositories that executes the given multi-result query. See Ecto.Adapters.SQL.query_many!/4 for more information.","ref":"ExampleApplication.Repo.html#query_many!/3","title":"ExampleApplication.Repo.query_many!/3","type":"function"},{"doc":"A convenience function for SQL-based repositories that executes the given multi-result query. See Ecto.Adapters.SQL.query_many/4 for more information.","ref":"ExampleApplication.Repo.html#query_many/3","title":"ExampleApplication.Repo.query_many/3","type":"function"},{"doc":"Callback implementation for Ecto.Repo.reload!/2 .","ref":"ExampleApplication.Repo.html#reload!/2","title":"ExampleApplication.Repo.reload!/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.reload/2 .","ref":"ExampleApplication.Repo.html#reload/2","title":"ExampleApplication.Repo.reload/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.rollback/1 .","ref":"ExampleApplication.Repo.html#rollback/1","title":"ExampleApplication.Repo.rollback/1","type":"function"},{"doc":"Callback implementation for Ecto.Repo.start_link/1 .","ref":"ExampleApplication.Repo.html#start_link/1","title":"ExampleApplication.Repo.start_link/1","type":"function"},{"doc":"Callback implementation for Ecto.Repo.stop/1 .","ref":"ExampleApplication.Repo.html#stop/1","title":"ExampleApplication.Repo.stop/1","type":"function"},{"doc":"Callback implementation for Ecto.Repo.stream/2 .","ref":"ExampleApplication.Repo.html#stream/2","title":"ExampleApplication.Repo.stream/2","type":"function"},{"doc":"A convenience function for SQL-based repositories that translates the given query to SQL. See Ecto.Adapters.SQL.to_sql/3 for more information.","ref":"ExampleApplication.Repo.html#to_sql/2","title":"ExampleApplication.Repo.to_sql/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.transaction/2 .","ref":"ExampleApplication.Repo.html#transaction/2","title":"ExampleApplication.Repo.transaction/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.update!/2 .","ref":"ExampleApplication.Repo.html#update!/2","title":"ExampleApplication.Repo.update!/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.update/2 .","ref":"ExampleApplication.Repo.html#update/2","title":"ExampleApplication.Repo.update/2","type":"function"},{"doc":"Callback implementation for Ecto.Repo.update_all/3 .","ref":"ExampleApplication.Repo.html#update_all/3","title":"ExampleApplication.Repo.update_all/3","type":"function"},{"doc":"","ref":"ExampleApplication.Users.html","title":"ExampleApplication.Users","type":"module"},{"doc":"","ref":"ExampleApplication.Users.html#insert/1","title":"ExampleApplication.Users.insert/1","type":"function"},{"doc":"","ref":"ExampleApplication.Users.html#update/2","title":"ExampleApplication.Users.update/2","type":"function"},{"doc":"","ref":"ExampleApplication.Users.User.html","title":"ExampleApplication.Users.User","type":"module"},{"doc":"","ref":"ExampleApplication.Users.User.html#changeset/2","title":"ExampleApplication.Users.User.changeset/2","type":"function"},{"doc":"A back-pressured backfill executor for Ecto repositories.","ref":"readme.html","title":"EctoBackfiller","type":"extras"},{"doc":"def deps do [ { :ecto_backfiller , &quot;~&gt; 0.1.0-dev&quot; } ] end","ref":"readme.html#installation","title":"EctoBackfiller - Installation","type":"extras"},{"doc":"Docs can be found at https://hexdocs.pm/ecto_backfiller .","ref":"readme.html#documentation","title":"EctoBackfiller - Documentation","type":"extras"},{"doc":"Execute the following setup commands: mix ecto . create mix ecto . migrate iex - S mix Then follow the documentation guide.","ref":"readme.html#running-the-example-application","title":"EctoBackfiller - Running the example application","type":"extras"}]